#include "label.h"
#include "part.h"
#include "style.h"

using namespace std;

namespace Msp {
namespace GLtk {

Label::Label(const string &t)
{
	focusable = false;
	set_text(t);
}

void Label::set_text(const string &t)
{
	text = t;
	signal_autosize_changed.emit();
	rebuild();
}

void Label::autosize_special(const Part &part, Geometry &ageom) const
{
	if(part.get_name()=="text")
		text.autosize(part, ageom);
}

void Label::rebuild_special(const Part &part)
{
	if(part.get_name()=="text")
		text.build(part, state, geom, part_cache);
}

void Label::on_style_change()
{
	text.set_style(style);
}


Label::Loader::Loader(Label &l):
	DataFile::DerivedObjectLoader<Label, Widget::Loader>(l)
{
	add("text", &Loader::text);
}

void Label::Loader::text(const string &t)
{
	obj.text = t;
}

} // namespace GLtk
} // namespace Msp
